Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(172)

Unified Diff: net/tools/transport_security_state_generator/transport_security_state_entry.h

Issue 2632073002: Rename domain_security_preload_generator. (Closed)
Patch Set: rebase & comment rsleevi Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/tools/transport_security_state_generator/transport_security_state_entry.h
diff --git a/net/tools/domain_security_preload_generator/domain_security_entry.h b/net/tools/transport_security_state_generator/transport_security_state_entry.h
similarity index 57%
rename from net/tools/domain_security_preload_generator/domain_security_entry.h
rename to net/tools/transport_security_state_generator/transport_security_state_entry.h
index e9d01f3cd257639980a8f3dac7a62f72980f2635..9a3cff479e939c3d08dff350ed329e538fd25276 100644
--- a/net/tools/domain_security_preload_generator/domain_security_entry.h
+++ b/net/tools/transport_security_state_generator/transport_security_state_entry.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef NET_TOOLS_DOMAIN_SECURITY_PRELOAD_GENERATOR_DOMAIN_SECURITY_ENTRY_H_
-#define NET_TOOLS_DOMAIN_SECURITY_PRELOAD_GENERATOR_DOMAIN_SECURITY_ENTRY_H_
+#ifndef NET_TOOLS_TRANSPORT_SECURITY_STATE_GENERATOR_DOMAIN_SECURITY_ENTRY_H_
+#define NET_TOOLS_TRANSPORT_SECURITY_STATE_GENERATOR_DOMAIN_SECURITY_ENTRY_H_
#include <memory>
#include <string>
@@ -13,10 +13,10 @@ namespace net {
namespace transport_security_state {
-// DomainSecurityEntry represents a preloaded entry.
-struct DomainSecurityEntry {
- DomainSecurityEntry();
- ~DomainSecurityEntry();
+// TransportSecurityStateEntry represents a preloaded entry.
+struct TransportSecurityStateEntry {
+ TransportSecurityStateEntry();
+ ~TransportSecurityStateEntry();
std::string hostname;
@@ -34,21 +34,22 @@ struct DomainSecurityEntry {
std::string expect_staple_report_uri;
};
-using DomainSecurityEntries = std::vector<std::unique_ptr<DomainSecurityEntry>>;
+using TransportSecurityStateEntries =
+ std::vector<std::unique_ptr<TransportSecurityStateEntry>>;
// TODO(Martijnc): Remove the domain IDs from the preload format.
// https://crbug.com/661206.
using DomainIDList = std::vector<std::string>;
// ReversedEntry points to a DomainSecurityEntry and contains the reversed
// hostname for that entry. This is used to construct the trie.
struct ReversedEntry {
ReversedEntry(std::vector<uint8_t> reversed_name,
- const DomainSecurityEntry* entry);
+ const TransportSecurityStateEntry* entry);
~ReversedEntry();
std::vector<uint8_t> reversed_name;
- const DomainSecurityEntry* entry;
+ const TransportSecurityStateEntry* entry;
};
using ReversedEntries = std::vector<std::unique_ptr<ReversedEntry>>;
@@ -57,4 +58,4 @@ using ReversedEntries = std::vector<std::unique_ptr<ReversedEntry>>;
} // namespace net
-#endif // NET_TOOLS_DOMAIN_SECURITY_PRELOAD_GENERATOR_DOMAIN_SECURITY_ENTRY_H_
+#endif // NET_TOOLS_TRANSPORT_SECURITY_STATE_GENERATOR_DOMAIN_SECURITY_ENTRY_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -34,21 +34,22 @@ struct DomainSecurityEntry {
// https://crbug.com/661206.
using DomainIDList = std::vector<std::string>;
-// ReversedEntry points to a DomainSecurityEntry and contains the reversed
-// hostname for that entry. This is used to construct the trie.
+// ReversedEntry points to a TransportSecurityStateEntry and contains the
+// reversed hostname for that entry. This is used to construct the trie.
struct ReversedEntry {
ReversedEntry(std::vector<uint8_t> reversed_name,